<div align="center">
<img src="https://bodywork-media.s3.eu-west-2.amazonaws.com/website_logo_transparent_background_full.png"/>
</div>
---

# Bodywork Pipeline Utilities

Utilities for helping with pipeline development and integration with 3rd party MLOps services.
